@@ -1,4 +1,4 @@
-package LedgerSMB::Installer::OS::unix v0.999.4;
+package LedgerSMB::Installer::OS::unix v0.999.5;
 
 use v5.20;
 use experimental qw(signatures);
@@ -109,7 +109,8 @@ sub generate_start_script($self, $installpath, $locallib) {
       cd $installpath
       exec $^X \\
           -I $installpath/lib \\
-          -I $installpath/$locallib_lib \\
+          -I $installpath/old/lib \\
+          -I $locallib_lib \\
           $starman \\
           --listen 0.0.0.0:5762 \\
           --workers \${LSMB_WORKERS:-5} \\
